from distutils.core import setup
from distutils.extension import Extension

ExtensionClass = Extension(name = 'ExtensionClass',
                           sources = ['ExtensionClass/src/ExtensionClass.c'])

Acquisition = Extension(name = 'Acquisition',
                        sources = ['ExtensionClass/src/Acquisition.c'])

ComputedAttribute = Extension(name = 'ComputedAttribute',
                       sources = ['ExtensionClass/src/ComputedAttribute.c'])

MethodObject = Extension(name = 'MethodObject',
                         sources = ['ExtensionClass/src/MethodObject.c'])

Missing = Extension(name = 'Missing',
                    sources = ['ExtensionClass/src/Missing.c'])

MultiMapping = Extension(name = 'MultiMapping',
                         sources = ['ExtensionClass/src/MultiMapping.c'])

Record = Extension(name = 'Record', sources = ['ExtensionClass/src/Record.c'])

Sync = Extension(name = 'Sync', sources = ['ExtensionClass/src/Sync.c'])

ThreadLock = Extension(name = 'ThreadLock',
                       sources = ['ExtensionClass/src/ThreadLock.c'])

include = ['ExtensionClass/src', 'ZODB']

cPersistence = Extension(name = 'ZODB.cPersistence',
                         include_dirs = include,
                         sources= ['ZODB/cPersistence.c']
                         )

cPickleCache = Extension(name = 'ZODB.cPickleCache',
                         include_dirs = include,
                         sources= ['ZODB/cPickleCache.c']
                         )

TimeStamp = Extension(name = 'ZODB.TimeStamp',
                      define_macros = [('USE_EXTENSION_CLASS', 1)],
                      include_dirs = include,
                      sources= ['ZODB/TimeStamp.c']
                      )

coptimizations = Extension(name = 'ZODB.coptimizations',
                           include_dirs = include,
                           sources= ['ZODB/coptimizations.c']
                           )

winlock = Extension(name = 'ZODB.winlock',
                    include_dirs = include,
                    sources = ['ZODB/winlock.c']
                    )

oob = Extension(name = "BTrees._OOBTree",
                include_dirs = include,
                sources = ['BTrees/_OOBTree.c'],
                )

oib = Extension(name = "BTrees._OIBTree",
                include_dirs = include,
                sources = ['BTrees/_OIBTree.c'],
                )

iib = Extension(name = "BTrees._IIBTree",
                include_dirs = include,
                sources = ['BTrees/_IIBTree.c'],
                define_macros = [('EXCLUDE_INTSET_SUPPORT', None)],
                )

iob = Extension(name = "BTrees._IOBTree",
                include_dirs = include,
                sources = ['BTrees/_IOBTree.c'],
                define_macros = [('EXCLUDE_INTSET_SUPPORT', None)],
                )

fsb = Extension(name = "BTrees._fsBTree",
                include_dirs = include,
                sources = ['BTrees/_fsBTree.c'],
                define_macros = [('EXCLUDE_INTSET_SUPPORT', None)],
                )

packages = ['BTrees', 'BTrees.tests',
            'ZEO', 'ZEO.tests',
            'ZODB', 'ZODB.tests',
            "Persistence",
            "ThreadedAsync",
            "zLOG", "zLOG.tests",
            "zdaemon",                  
            ]

try:
    import bsddb3
except ImportError:
    pass
else:
    packages.extend(["bsddb3Storage", "bsddb3Storage.tests"])

setup(name="StandaloneZODB",
      version="1.0",
      description="Zope Object Database: object database and persistence",
      maintainer="Zope Corp.",
      maintainer_email="zodb-dev@zope.org",
      url = "http://www.zope.org/Wikis/ZODB/FrontPage",

      package_dir = {'bsddb3Storage': 'bsddb3Storage/bsddb3Storage'},
      packages = packages,
      ext_modules = [ExtensionClass, Acquisition, ComputedAttribute,
                     MethodObject, Missing, MultiMapping, Sync,
                     ThreadLock, Record, cPersistence, cPickleCache,
                     TimeStamp, coptimizations, winlock, oob, oib,
                     iib, iob, fsb,
                     ],
      headers = ['ExtensionClass/src/ExtensionClass.h', 'ZODB/cPersistence.h'],
      
      )
